summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPhil Sainty <psainty@orcon.net.nz>2019-12-08 23:35:48 +1300
committerPhil Sainty <psainty@orcon.net.nz>2020-08-04 01:44:52 +1200
commit19f8f36f11cf5ae62a7b92dc1496c72db4d377b3 (patch)
tree54fea222b3acf5297e97693de172476691df030b
parent83bc4ad369b3c31abafb7f939711da1ba13416ba (diff)
downloademacs-19f8f36f11cf5ae62a7b92dc1496c72db4d377b3.tar.gz
; * lisp/so-long.el (so-long-variable-overrides): Improve doc
-rw-r--r--lisp/so-long.el15
1 files changed, 13 insertions, 2 deletions
diff --git a/lisp/so-long.el b/lisp/so-long.el
index 68614ca0023..b3596bdab7b 100644
--- a/lisp/so-long.el
+++ b/lisp/so-long.el
@@ -783,7 +783,18 @@ to their original states.
The combination of `line-move-visual' (enabled) and `truncate-lines' (disabled)
is important for maximising responsiveness when moving vertically within an
extremely long line, as otherwise the full length of the line may need to be
-scanned to find the next position."
+scanned to find the next position.
+
+Bidirectional text display -- especially handling the large quantities of
+nested parentheses which are liable to occur in minified programming code --
+can be very expensive for extremely long lines, and so this support is disabled
+by default (insofar as is supported; in particular `bidi-inhibit-bpa' is not
+available in Emacs versions < 27). For more information refer to info node
+`(emacs) Bidirectional Editing' and info node `(elisp) Bidirectional Display'.
+
+Buffers are made read-only by default to prevent potentially-slow editing from
+occurring inadvertantly, as buffers with excessively long lines are likely not
+intended to be edited manually."
:type '(alist :key-type (variable :tag "Variable")
:value-type (sexp :tag "Value"))
:options '((bidi-inhibit-bpa boolean)
@@ -1863,7 +1874,7 @@ If it appears in `%s', you should remove it."
; LocalWords: defadvice nadvice whitespace ie bos eos eobp origmode un Un setq
; LocalWords: docstring auf Wiedersehen longlines alist autoload Refactored Inc
; LocalWords: MERCHANTABILITY RET REGEXP VAR ELPA WS mitigations EmacsWiki eval
; LocalWords: rx filename filenames
;; So long, farewell, auf Wiedersehen, goodbye
;; You have to go, this code is minified
@@ -1863,7 +1874,7 @@ If it appears in `%s', you should remove it."
; LocalWords: docstring auf Wiedersehen longlines alist autoload Refactored Inc
; LocalWords: MERCHANTABILITY RET REGEXP VAR ELPA WS mitigations EmacsWiki eval
-; LocalWords: rx filename filenames
+; LocalWords: rx filename filenames bidi bpa
;; So long, farewell, auf Wiedersehen, goodbye
;; You have to go, this code is minified